@@ -1,68 +1,70 @@
 #' Choropleth
-#' 
+#'
 #' Draw maps.
-#' 
+#'
 #' @inheritParams e_bar
 #' @param serie Values to plot.
 #' @param map Map type.
 #' @param coord_system Coordinate system to use, one of \code{cartesian3D}, \code{geo3D}, \code{globe}.
 #' @param rm_x,rm_y Whether to remove x and y axis, defaults to \code{TRUE}.
 #' @param id,value,height Columns corresponding to registered map.
-#' 
-#' @examples 
+#'
+#' @examples
 #' \dontrun{
 #' choropleth <- data.frame(
-#'   countries = c("France", "Brazil", "China", "Russia", "Canada", "India", "United States",
-#'                 "Argentina", "Australia"),
+#'   countries = c(
+#'     "France", "Brazil", "China", "Russia", "Canada", "India", "United States",
+#'     "Argentina", "Australia"
+#'   ),
 #'   values = round(runif(9, 10, 25))
 #' )
-#' 
-#' choropleth %>% 
-#'   e_charts(countries) %>% 
-#'   e_map(values) %>% 
+#'
+#' choropleth %>%
+#'   e_charts(countries) %>%
+#'   e_map(values) %>%
 #'   e_visual_map(min = 10, max = 25)
-#' 
-#' choropleth %>% 
-#'   e_charts(countries) %>% 
-#'   e_map_3d(values, shading = "lambert") %>% 
+#'
+#' choropleth %>%
+#'   e_charts(countries) %>%
+#'   e_map_3d(values, shading = "lambert") %>%
 #'   e_visual_map(min = 10, max = 30)
-#'         
+#'
 #' # custom
 #' buildings <- jsonlite::read_json(
 #'   paste0(
-#'     "https://ecomfe.github.io/echarts-examples/",
-#'     "public/data-gl/asset/data/buildings.json"
+#'     "https://echarts.apache.org/examples/",
+#'     "data-gl/asset/data/buildings.json"
 #'   )
 #' )
-#' 
-#' heights <- purrr::map(buildings$features, "properties") %>% 
-#'   purrr::map("height") %>% 
+#'
+#' heights <- purrr::map(buildings$features, "properties") %>%
+#'   purrr::map("height") %>%
 #'   unlist()
-#'   
-#' names <- purrr::map(buildings$features, "properties") %>% 
-#'   purrr::map("name") %>% 
+#'
+#' names <- purrr::map(buildings$features, "properties") %>%
+#'   purrr::map("name") %>%
 #'   unlist()
-#'   
+#'
 #' data <- dplyr::tibble(
 #'   name = names,
 #'   value = round(runif(length(names), 0, 1), 6),
 #'   height = heights / 10
 #' )
-#' 
-#' data %>% 
-#'   e_charts() %>% 
+#'
+#' data %>%
+#'   e_charts() %>%
 #'   e_map_register("buildings", buildings) %>%
-#'   e_map_3d_custom(name, value, height) %>% 
+#'   e_map_3d_custom(name, value, height) %>%
 #'   e_visual_map(
 #'     show = FALSE,
 #'     min = 0.4,
 #'     max = 1
-#'   ) 
-#'   
+#'   )
+#'
 #' # timeline
 #' choropleth <- data.frame(
-#'     countries = rep(choropleth$countries, 3)
-#'   ) %>% 
+#'   countries = rep(choropleth$countries, 3)
+#' ) %>%
 #'   dplyr::mutate(
 #'     grp = c(
 #'       rep(2016, nrow(choropleth)),
@@ -71,84 +73,85 @@
 #'     ),
 #'     values = runif(27, 1, 10)
 #'   )
-#'   
-#' choropleth %>% 
-#'   group_by(grp) %>% 
-#'   e_charts(countries, timeline = TRUE) %>% 
-#'   e_map(values) %>% 
+#'
+#' choropleth %>%
+#'   group_by(grp) %>%
+#'   e_charts(countries, timeline = TRUE) %>%
+#'   e_map(values) %>%
 #'   e_visual_map(min = 1, max = 10)
-#'   
-#' choropleth %>% 
-#'   group_by(grp) %>% 
-#'   e_charts(countries, timeline = TRUE) %>% 
-#'   e_map_3d(values) %>% 
+#'
+#' choropleth %>%
+#'   group_by(grp) %>%
+#'   e_charts(countries, timeline = TRUE) %>%
+#'   e_map_3d(values) %>%
 #'   e_visual_map(min = 1, max = 10)
 #' }
-#' 
-#' @seealso \code{\link{e_country_names}}, 
-#' \href{https://echarts.apache.org/en/option.html#series-map}{Additional map arguments}, 
-#' \href{http://echarts.baidu.com/option-gl.html#series-map3D}{Additional map 3D arguments}
-#' 
+#'
+#' @seealso \code{\link{e_country_names}},
+#' \href{https://echarts.apache.org/en/option.html#series-map}{Additional map arguments},
+#' \href{https://echarts.apache.org/en/option-gl.html#series-map3D}{Additional map 3D arguments}
+#'
 #' @rdname map
 #' @export
-e_map <- function(e, serie, map = "world", name = NULL, rm_x = TRUE, rm_y = TRUE, ...){
-  
-  if(missing(e))
+e_map <- function(e, serie, map = "world", name = NULL, rm_x = TRUE, rm_y = TRUE, ...) {
+  if (missing(e)) {
     stop("must pass e", call. = FALSE)
-  
-  if(!missing(serie))
+  }
+
+  if (!missing(serie)) {
     sr <- deparse(substitute(serie))
-  else
+  } else {
     sr <- NULL
-  
+  }
+
   e_map_(e, sr, map, name, rm_x, rm_y, ...)
 }
 
 #' @rdname map
 #' @export
-e_map_ <- function(e, serie = NULL, map = "world", name = NULL, rm_x = TRUE, rm_y = TRUE, ...){
-  
-  if(missing(e))
+e_map_ <- function(e, serie = NULL, map = "world", name = NULL, rm_x = TRUE, rm_y = TRUE, ...) {
+  if (missing(e)) {
     stop("must pass e", call. = FALSE)
-  
+  }
+
   e <- .rm_axis(e, rm_x, "x")
   e <- .rm_axis(e, rm_y, "y")
-  
-  for(i in 1:length(e$x$data)){
-    
+
+  for (i in 1:length(e$x$data)) {
     app <- list(
       type = "map",
       map = map,
       name = name,
       ...
     )
-    
-    if(!is.null(serie)){
+
+    if (!is.null(serie)) {
       data <- .build_data2(e$x$data[[i]], serie)
       data <- .add_bind2(e, data, e$x$mapping$x, i = i)
       app_data <- list(data = data)
     } else {
       app_data <- list()
     }
-    
-    if(!e$x$tl){
-      
-      if(is.null(name) && !is.null(serie))
+
+    if (!e$x$tl) {
+      if (is.null(name) && !is.null(serie)) {
         app$name <- serie
-      
+      }
+
       app <- append(app, app_data)
-      
+
       e$x$opts$series <- append(e$x$opts$series, list(app))
-    } else
+    } else {
       e$x$opts$options[[i]]$series <- append(e$x$opts$options[[i]]$series, list(app_data))
-    
+    }
   }
-  
-  if(isTRUE(e$x$tl))
+
+  if (isTRUE(e$x$tl)) {
     e$x$opts$baseOption$series <- append(e$x$opts$baseOption$series, list(app))
+  }
 
 
-  if(map == "world"){
+  if (map == "world") {
     # add dependency
     path <- system.file("htmlwidgets/lib/echarts-4.8.0", package = "echarts4r")
     dep <- htmltools::htmlDependency(
@@ -160,42 +163,43 @@ e_map_ <- function(e, serie = NULL, map = "world", name = NULL, rm_x = TRUE, rm_
 
     e$dependencies <- append(e$dependencies, list(dep))
   }
-  
+
   e
 }
 
 #' @rdname map
 #' @export
-e_map_3d <- function(e, serie, map = "world", name = NULL, coord_system = NULL, rm_x = TRUE, rm_y = TRUE, ...){
-  if(missing(e))
+e_map_3d <- function(e, serie, map = "world", name = NULL, coord_system = NULL, rm_x = TRUE, rm_y = TRUE, ...) {
+  if (missing(e)) {
     stop("must pass e", call. = FALSE)
-  
-  if(!missing(serie))
+  }
+
+  if (!missing(serie)) {
     sr <- deparse(substitute(serie))
-  else
+  } else {
     sr <- NULL
-  
+  }
+
   e_map_3d_(e = e, serie = sr, map, name, coord_system, rm_x, rm_y, ...)
 }
 
 #' @rdname map
 #' @export
-e_map_3d_ <- function(e, serie = NULL, map = "world", name = NULL, coord_system = NULL, rm_x = TRUE, rm_y = TRUE, ...){
-  
-  if(missing(e))
+e_map_3d_ <- function(e, serie = NULL, map = "world", name = NULL, coord_system = NULL, rm_x = TRUE, rm_y = TRUE, ...) {
+  if (missing(e)) {
     stop("must pass e", call. = FALSE)
-  
+  }
+
   e <- .rm_axis(e, rm_x, "x")
   e <- .rm_axis(e, rm_y, "y")
-  
-  for(i in 1:length(e$x$data)){
-    
-    if(!is.null(serie)){
+
+  for (i in 1:length(e$x$data)) {
+    if (!is.null(serie)) {
       data <- .build_data2(e$x$data[[i]], serie)
       data <- .add_bind2(e, data, e$x$mapping$x, i = i)
       dat <- data
     }
-    
+
     app <- list(
       type = "map3D",
       map = map,
@@ -203,28 +207,27 @@ e_map_3d_ <- function(e, serie = NULL, map = "world", name = NULL, coord_system
       name = name,
       ...
     )
-    
+
     app_data <- list(data = data)
-    
-    if(!e$x$tl){
-      
-      if(is.null(name) && !is.null(serie))
+
+    if (!e$x$tl) {
+      if (is.null(name) && !is.null(serie)) {
         app$name <- serie
-      
+      }
+
       app <- append(app, app_data)
-      
+
       e$x$opts$series <- append(e$x$opts$series, list(app))
-      
     } else {
       e$x$opts$options[[i]]$series <- append(e$x$opts$options[[i]]$series, list(app_data))
     }
-    
   }
-  
-  if(isTRUE(e$x$tl))
-    e$x$opts$baseOption$series <- append(e$x$opts$baseOption$series, list(app))
 
-  if(map == "world"){
+  if (isTRUE(e$x$tl)) {
+    e$x$opts$baseOption$series <- append(e$x$opts$baseOption$series, list(app))
+  }
+
+  if (map == "world") {
     # add dependency
     path <- system.file("htmlwidgets/lib/echarts-4.8.0", package = "echarts4r")
     dep <- htmltools::htmlDependency(
@@ -246,123 +249,135 @@ e_map_3d_ <- function(e, serie = NULL, map = "world", name = NULL, coord_system
     script = "echarts-gl.min.js"
   )
 
-  e$dependencies <- append(e$dependencies, list(dep)) 
-  
+  e$dependencies <- append(e$dependencies, list(dep))
+
   e
 }
 
 #' @rdname map
 #' @export
-e_map_3d_custom <- function(e, id, value, height, map = NULL, name = NULL, rm_x = TRUE, rm_y = TRUE, ...){
-  
-  if(missing(e))
+e_map_3d_custom <- function(e, id, value, height, map = NULL, name = NULL, rm_x = TRUE, rm_y = TRUE, ...) {
+  if (missing(e)) {
     stop("must pass e", call. = FALSE)
-  
-  if(missing(id) || missing(value) || missing(height))
+  }
+
+  if (missing(id) || missing(value) || missing(height)) {
     stop("must pass id, value, and height", call. = FALSE)
-  
-  if(is.null(map) && length(e$x$registerMap[[1]]$mapName))
+  }
+
+  if (is.null(map) && length(e$x$registerMap[[1]]$mapName)) {
     map <- unlist(e$x$registerMap[[1]]$mapName)
-  else
+  } else if (is.null(map)) { # fix when map value is not NULL
     stop("not map registered, see e_map_register", call. = FALSE)
-  
-  e$x$renderer <- "webgl"
-  
+  }
+
+  e$x$renderer <- "webgl" # 'canvas' works also, maybe even more efficient
+
   e <- .rm_axis(e, rm_x, "x")
   e <- .rm_axis(e, rm_y, "y")
-  
+
   app <- list(
     type = "map3D",
     map = map,
     ...
   )
-  
-  if(!is.null(name))
+
+  if (!is.null(name)) {
     app$name <- name
-  
+  }
+
   name_quo <- dplyr::enquo(id)
   value_quo <- dplyr::enquo(value)
   height_quo <- dplyr::enquo(height)
-  
-  data <- e$x$data[[1]] %>% 
+
+  data <- e$x$data[[1]] %>%
     dplyr::select(
       name = !!name_quo,
       value = !!value_quo,
       height = !!height_quo
-    ) %>% 
+    ) %>%
     apply(1, as.list)
-  
+
   app$data <- data
-  
+
   e$x$opts$series <- append(e$x$opts$series, list(app))
-  
+
+  # add dependency
+  path <- system.file("htmlwidgets/lib/echarts-4.8.0", package = "echarts4r")
+  dep <- htmltools::htmlDependency(
+    name = "echarts-gl",
+    version = "1.1.2",
+    src = c(file = path),
+    script = "echarts-gl.min.js"
+  )
+  e$dependencies <- append(e$dependencies, list(dep))
+
   e
 }
 
 #' Register map
-#' 
-#' Register a \href{http://geojson.org/}{geojson} map.
-#' 
+#'
+#' Register a \href{https://geojson.org/}{geojson} map.
+#'
 #' @param e An \code{echarts4r} object as returned by \code{\link{e_charts}}.
 #' @param name Name of map, to use in \code{\link{e_map}}.
-#' @param json \href{http://geojson.org/}{Geojson}.
+#' @param json \href{https://geojson.org/}{Geojson}.
 #' @param async Whether to read the file asynchronously.
 #' @param session A valid Shiny session.
-#' 
+#'
 #' @details \code{e_map_register_p} is not truly a proxy as it does not require
 #' a chart to function. While the function \code{e_map_register_ui} is meant to
 #' register the map globally in the Shiny UI, not that then \code{json} must be accessible
 #' from the UI (generally www folder).
-#' 
-#' @examples 
+#'
+#' @examples
 #' \dontrun{
-#' json <- jsonlite::read_json("http://www.echartsjs.com/gallery/data/asset/geo/USA.json")
+#' json <- jsonlite::read_json("https://echarts.apache.org/examples/data/asset/geo/USA.json")
 #'
 #' USArrests %>%
 #'   dplyr::mutate(states = row.names(.)) %>%
 #'   e_charts(states) %>%
 #'   e_map_register("USA", json) %>%
-#'   e_map(Murder, map = "USA") %>% 
+#'   e_map(Murder, map = "USA") %>%
 #'   e_visual_map(Murder)
 #' }
-#' 
+#'
 #' @rdname e_map_register
 #' @export
 e_map_register <- function(e, name, json) UseMethod("e_map_register")
 
 #' @export
 #' @method e_map_register echarts4r
-e_map_register.echarts4r <- function(e, name, json){
-  
-  if(!length(e$x$registerMap))
+e_map_register.echarts4r <- function(e, name, json) {
+  if (!length(e$x$registerMap)) {
     e$x$registerMap <- list()
-  
+  }
+
   opts <- list(
     mapName = name,
     geoJSON = json
   )
-  
+
   e$x$registerMap <- append(e$x$registerMap, list(opts))
   e
 }
 
 #' @rdname e_map_register
 #' @export
-e_map_register_p <- function(name, json, async = FALSE, session = shiny::getDefaultReactiveDomain()){
-  
+e_map_register_p <- function(name, json, async = FALSE, session = shiny::getDefaultReactiveDomain()) {
   opts <- list(
     mapAsync = async,
     mapName = name,
     geoJSON = json
   )
-  
+
   session$sendCustomMessage("e_register_map", opts)
   invisible()
 }
 
 #' @rdname e_map_register
 #' @export
-e_map_register_ui <- function(name, json, async = FALSE){
+e_map_register_ui <- function(name, json, async = FALSE) {
   async <- paste0(tolower(async))
   script <- paste0("
     $.ajax({ 
@@ -372,57 +387,59 @@ e_map_register_ui <- function(name, json, async = FALSE){
         success: function(map){ 
           echarts.registerMap('", name, "', map);
         } 
-      });"
-    )
+      });")
   shiny::tags$script(
     script
   )
 }
 
 #' Mapbox
-#' 
+#'
 #' Use mapbox.
-#' 
+#'
 #' @inheritParams e_bar
 #' @param token Your mapbox token from \href{https://www.mapbox.com/}{mapbox}.
 #' @param ... Any option.
-#' 
-#' @examples 
+#'
+#' @examples
 #' \dontrun{
-#' url <- paste0("https://ecomfe.github.io/echarts-examples/",
-#'               "public/data-gl/asset/data/population.json")
+#' url <- paste0(
+#'   "https://echarts.apache.org/examples/",
+#'   "data-gl/asset/data/population.json"
+#' )
 #' data <- jsonlite::fromJSON(url)
 #' data <- as.data.frame(data)
 #' names(data) <- c("lon", "lat", "value")
-#' 
-#' data %>% 
-#'   e_charts(lon) %>% 
+#'
+#' data %>%
+#'   e_charts(lon) %>%
 #'   e_mapbox(
 #'     token = "YOUR_MAPBOX_TOKEN",
 #'     style = "mapbox://styles/mapbox/dark-v9"
-#'   ) %>% 
-#'   e_bar_3d(lat, value, coord_system = "mapbox") %>% 
+#'   ) %>%
+#'   e_bar_3d(lat, value, coord_system = "mapbox") %>%
 #'   e_visual_map()
 #' }
-#' 
+#'
 #' @note Mapbox may not work properly in the RSudio console.
-#' 
-#' @seealso \href{http://www.echartsjs.com/option-gl.html#mapbox3D.style}{Official documentation},
-#' \href{https://www.mapbox.com/mapbox-gl-js/api/}{mapbox documentation}
-#' 
+#'
+#' @seealso \href{https://echarts.apache.org/en/option-gl.html#mapbox3D.style}{Official documentation},
+#' \href{https://docs.mapbox.com/mapbox-gl-js/api/}{mapbox documentation}
+#'
 #' @name mapbox
 #' @export
-e_mapbox <- function(e, token, ...){
-  
-  if(missing(token))
+e_mapbox <- function(e, token, ...) {
+  if (missing(token)) {
     stop("missing token", call. = FALSE)
-  
+  }
+
   e$x$mapboxToken <- token
-  
-  if(!e$x$tl)
+
+  if (!e$x$tl) {
     e$x$opts$mapbox <- list(...)
-  else
+  } else {
     e$x$opts$baseOption$mapbox <- list(...)
+  }
 
   # add dependency
   path <- system.file("htmlwidgets/lib/mapbox", package = "echarts4r")
@@ -435,6 +452,6 @@ e_mapbox <- function(e, token, ...){
   )
 
   e$dependencies <- append(e$dependencies, list(dep))
-  
+
   e
 }
